@@ -16,13 +16,14 @@ import yaml
 
 
 # GLOBAL CONSTANTS
-__version__ = "1.0"
+__version__ = "1.2"
 __date__ = "Feb-2022"
 
 background = 0
 middleground = 1
 foreground = 2
-colors = {"white": "#ffffff", "red": "#fbd8ea", "blue": "#c4e2fa", "yellow": "#fff4d6", "violet": "#dad0ef", "green": "#edf5dc", "turquoise": "#d4f3f6"}
+colors = {"white": "#ffffff", "red": "#fbd8ea", "blue": "#c4e2fa", "yellow": "#fff4d6", "violet": "#dad0ef", "green": "#edf5dc", "aqua": "#d4f3f6"}
+
 
 # FUNCTIONS
 
@@ -229,6 +230,11 @@ def render_month_grid(tl, metrics, style, xoffset, starty, endy):
     return(svg_out)
 
 
+def short_date_string(d: date):
+    temp = parse_date(d)
+    return(temp.strftime("%d-%b"))
+
+
 def render_twolines(date_string, y, text1, text2, metrics, xnudge=0, align="center"):
     """render date and caption in two lines
 
@@ -259,7 +265,7 @@ def render_twolines(date_string, y, text1, text2, metrics, xnudge=0, align="cent
     return(("", x))
 
 
-def alignment_solution(time_points, reference, metrics, xpadding=0, xnudge=0):
+def alignment_solution(time_points, reference, metrics, xpadding=0, xnudge=0, short_date=False):
     (textwidth_function, textheight_function, date_position_function, month_width, text_height, lineheight, min_scale_date, max_scale_date) = metrics
     """calculates the best alignment solution for time points
     
@@ -273,6 +279,7 @@ def alignment_solution(time_points, reference, metrics, xpadding=0, xnudge=0):
     The best sequence is returned as the alignment solution.
     """
     def _alg_solution(x: list, w: list, sequences: list):
+        """x is the list of timepoint positions, w is the list of label widths"""
         if len(x) == 0:
             return(sequences)
         else:
@@ -296,7 +303,11 @@ def alignment_solution(time_points, reference, metrics, xpadding=0, xnudge=0):
             return(_alg_solution(x, w, out))
 
     x = [date_position_function(parse_date(i["date"])) for i in time_points]
-    w = [max(textwidth_function(i["date"]), textwidth_function(i["caption"])) for i in time_points]
+    if short_date:
+        w = [max(textwidth_function(short_date_string(i["date"])), textwidth_function(i["caption"])) for i in time_points]
+    else:
+        w = [max(textwidth_function(i["date"]), textwidth_function(i["caption"])) for i in time_points]
+    # w = [max(textwidth_function(i["date"]), textwidth_function(i["caption"])) for i in time_points]
     temp = _alg_solution(x, w, [(0,[])])
     sequences = []
     for s in [i[1] for i in temp]:
@@ -311,7 +322,7 @@ def alignment_solution(time_points, reference, metrics, xpadding=0, xnudge=0):
     return([(d, a) for d, a in zip(time_points, sorted_sequences[0][5])])
 
 
-def bottom_alignment_solution(top_solution, metrics, xpadding=0, xnudge=0):
+def bottom_alignment_solution(top_solution, metrics, xpadding=0, xnudge=0, short_date=False):
     (textwidth_function, textheight_function, date_position_function, month_width, text_height, lineheight, min_scale_date, max_scale_date) = metrics
     
     timepoints = []
@@ -377,7 +388,7 @@ def render_segment(thread, y, metrics, style):
     return(out)
 
 
-def render_thread(thread, metrics, style, xoffset, yoffset=0):
+def render_thread(thread, metrics, style, xoffset, yoffset=0, short_date=True):
     (textwidth_function, textheight_function, date_position_function, month_width, text_height, lineheight, min_scale_date, max_scale_date) = metrics
     (lwd, xpadding, ypadding, threadoffset, linescaling) = style
 
@@ -391,13 +402,15 @@ def render_thread(thread, metrics, style, xoffset, yoffset=0):
         thread_tps = get_timepoints(thread["timepoints"])
         reference = ["center"] * len(thread_tps)
 
-        top_alignments = alignment_solution(thread_tps, reference, metrics, xpadding=datepadding, xnudge=xnudge)
-        bottom_alignments = bottom_alignment_solution(top_alignments, metrics)  
+        top_alignments = alignment_solution(thread_tps, reference, metrics, xpadding=datepadding, xnudge=xnudge, short_date=short_date)
+        bottom_alignments = bottom_alignment_solution(top_alignments, metrics, short_date=short_date)  
  
         # render top labels
         max_x = 0
         for (tp, a) in top_alignments:
-            (svg, x) = render_twolines(tp["date"], y, tp["date"], tp["caption"], metrics, xnudge=xnudge, align=a)
+            d = short_date_string(tp["date"]) if short_date else tp["date"]
+            # (svg, x) = render_twolines(tp["date"], y, tp["date"], tp["caption"], metrics, xnudge=xnudge, align=a)
+            (svg, x) = render_twolines(tp["date"], y, d, tp["caption"], metrics, xnudge=xnudge, align=a)
             svg_out += svg
             max_x = max(max_x, x)
         y += textheight_function("X") * 1.7 + lineheight + ypadding * 1.5
@@ -418,14 +431,16 @@ def render_thread(thread, metrics, style, xoffset, yoffset=0):
         # render bottom labels, if applicable
         if bottom_alignments:
             for tp, a in bottom_alignments:
-                (svg, x) = render_twolines(tp["date"], y, tp["date"], tp["caption"], metrics, xnudge=xnudge, align=a) 
+                d = short_date_string(tp["date"]) if short_date else tp["date"]
+                # (svg, x) = render_twolines(tp["date"], y, tp["date"], tp["caption"], metrics, xnudge=xnudge, align=a) 
+                (svg, x) = render_twolines(tp["date"], y, d, tp["caption"], metrics, xnudge=xnudge, align=a) 
                 svg_out += svg
                 max_x = max(max_x, x)
             y  += lineheight * 2
     return(["", "", svg_out, y + ypadding, max_x])
 
 
-def render_block(block, header_width, metrics, style, xoffset, yoffset=0):
+def render_block(block, header_width, metrics, style, xoffset, yoffset=0, short_date=False):
     """render block structure and threads included"""
     (textwidth_function, textheight_function, date_position_function, month_width, text_height, lineheight, min_scale_date, max_scale_date) = metrics
     (lwd, xpadding, ypadding, threadoffset, linescaling) = style
@@ -434,7 +449,7 @@ def render_block(block, header_width, metrics, style, xoffset, yoffset=0):
     out = ["", "", svg_text(5 + xpadding, y_top + lineheight, block["caption"], font_weight="bold"), yoffset + ypadding, 0]
 
     for thd in block["threads"]:
-        out = add_rendering(out, render_thread, thd, metrics, style, xoffset)
+        out = add_rendering(out, render_thread, thd, metrics, style, xoffset, short_date=short_date)
     out[-2] += ypadding
     y_bottom = out[-2]
     out[background] = svg_rect(5, y_top, header_width-5, y_bottom-y_top, lwd=0, fill_color=colors[block["color"]], fill_opacity=0.4)
@@ -455,7 +470,7 @@ def next_month_start(date):
     return(date.replace(month=date.month + 1, day=1))
 
 
-def render_tl(tl, fontsize=14, font="Arial", monthwidth=1, today=False, autowidth=False, datelines=False, grid="", linescaling=1, mindate=0, maxdate=0):
+def render_tl(tl, fontsize=14, font="Arial", monthwidth=1, today=False, autowidth=False, datelines=False, grid="", linescaling=1, mindate=0, maxdate=0, short_date=False):
     # init canvas for text metrics, make metrics
     canvas = cairo.Context(cairo.SVGSurface("temp.svg", 10, 10))
     canvas.select_font_face(font, cairo.FONT_SLANT_NORMAL, cairo.FONT_WEIGHT_NORMAL)
@@ -523,7 +538,7 @@ def render_tl(tl, fontsize=14, font="Arial", monthwidth=1, today=False, autowidt
 
     # render blocks
     for b in tl["blocks"]:
-        render_out = add_rendering(render_out, render_block, b, header_width, metrics, style, xoffset)
+        render_out = add_rendering(render_out, render_block, b, header_width, metrics, style, xoffset, short_date=short_date)
 
     # render month grid
     if grid:
@@ -589,7 +604,8 @@ def main(
     datelines: bool = typer.Option(False, "--show-datelines", "-d", help="Show datelines"),
     autowidth: bool = typer.Option(False, "--autowidth", "-a", help="Render width automatically"),
     linescaling: float = typer.Option(1, "--line-scaling", "-l", help="Line width scaling factor"),
-    all: bool = typer.Option(False, "-all", "-A", help="All options, equivalent to -atg"),
+    all: bool = typer.Option(False, "--all", "-A", help="All options, equivalent to -atg"),
+    shortdate: bool = typer.Option(False, "--short-date", "-r", help="Show only month and year in date lables"),
     output: str = typer.Option("", "--output", "-o", help="Output file name"),
     debug: bool = typer.Option(False, "--debug", "-D", help="Show debug output"),
     version: bool = typer.Option(False, "--version", help="Show version and exit", callback=version_callback)):
@@ -669,7 +685,7 @@ def main(
 
     # rendering
     try:
-        ([svg_out, y, max_x]) = render_tl(tl, fontsize=fontsize, monthwidth=monthwidth, today=today, autowidth=autowidth, datelines=datelines, grid=grid, linescaling=linescaling*1.2, mindate=min_scale_date, maxdate=max_scale_date)
+        ([svg_out, y, max_x]) = render_tl(tl, fontsize=fontsize, monthwidth=monthwidth, today=today, autowidth=autowidth, datelines=datelines, grid=grid, linescaling=linescaling*1.2, mindate=min_scale_date, maxdate=max_scale_date, short_date=shortdate)
 
         # adding svg boilerplate
         title = infile.stem
